@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "calfw-ical" "2.0"
+(define-package "calfw-ical" "20251030.845"
   "Calendar view for ical format."
   '((emacs "28.1")
     (calfw "2.0"))
   :url "https://github.com/haji-ali/emacs-calfw"
-  :commit "9cce503eb0e998389485a74b956884d218a960e2"
-  :revdesc "v2.0-0-g9cce503eb0e9"
+  :commit "57be107b20625c13ed010cb0f70a603a61d47629"
+  :revdesc "57be107b2062"
   :keywords '("calendar" "ical")
   :authors '(("SAKURAI Masashi" . "m.sakuraiatkiwanami.net"))
   :maintainers '(("Al Haji-Ali" . "abdo.haji.aliatgmail.com")))
